# Установка Gitea + Drone CI

Рассматривается установка на сервер от Selectel с параметрами 2c/4g/50GB и OS Debian 11

Предварительно надо установить [Docker и Docker-compose](https://docs.docker.com/engine/install/)

## Установка Gitea

Переходим туда, где хотим хранить Gitea (У меня `/srv/gitea`)

### `docker-compose.yml`:
```yaml
version: "3.3"

services:
  server:
    image: gitea/gitea
    container_name: gitea
    environment:
      - USER_UID=1001
      - USER_GID=1001
    restart: always
    volumes:
      - ./gitea:/data
      - /etc/timezone:/etc/timezone:ro
      - /etc/localtime:/etc/localtime:ro
      - /home/git/.ssh/:/data/git/.ssh
    ports:
      - "127.0.0.1:3000:3000"
      - "127.0.0.1:2222:22"
```

#### Пояснение:

Для **ssh forwarding**
используются: [(Подробнее)](https://docs.gitea.io/en-us/install-with-docker/#ssh-container-passthrough)

- `USER_UID`
- `USER_GID`
- `ports` section
- `.ssh` volumes

**`- ./gitea:/data` volume -** хранение репозиториев и прочей инфы

Делаем `docker-compose up -d`, проксируем запросы с `gitea.YOURDOMAIN` на `http://127.0.0.1:3000` любым удобным
способом (Nginx, Traefik)

После установки можно зайти в `gitea/gitea/conf/app.ini` и поменять что надо (Например Root URL)

### Для проброса SSH:

```shell
$ sudo useradd -m git
$ sudo -u git ssh-keygen -t ecdsa -C "Gitea Host Key"
$ sudo -u git cat /home/git/.ssh/id_ecdsa.pub | sudo -u git tee -a /home/git/.ssh/authorized_keys
$ sudo -u git chmod 600 /home/git/.ssh/authorized_keys
$ cat <<"EOF" | sudo tee /usr/local/bin/gitea
#!/bin/sh
ssh -p 2222 -o StrictHostKeyChecking=no git@127.0.0.1 "SSH_ORIGINAL_COMMAND=\"$SSH_ORIGINAL_COMMAND\" $0 $@"
EOF
sudo chmod +x /usr/local/bin/gitea
```

## Установка Drone CI (Если надо)

Лучше всего расскажет [оф. дока](https://docs.drone.io/server/provider/gitea/)

### `docker-compose.yml`:
```yaml
version: "3.3"

services:
  drone:
    image: drone/drone
    restart: always
    environment:
      DRONE_GITEA_CLIENT_ID: "gitea_oauth_client_id"
      DRONE_GITEA_CLIENT_SECRET: "gitea_oauth_client_secret"
      DRONE_GITEA_SERVER: "https://gitea.example.com"
      DRONE_RPC_SECRET: "drone_rpc_secret"
      DRONE_SERVER_HOST: "drone.example.com"
      DRONE_SERVER_PROTO: "https"
      DRONE_USER_CREATE: "username:gitea_admin_username,admin:true"
    ports:
      - "127.0.0.1:3001:80"
    volumes:
      - "./data:/data"

  drone-runner:
    image: drone/drone-runner-docker
    restart: always
    environment:
      DRONE_RUNNER_NAME: "runner-01"
      DRONE_RUNNER_CAPACITY: "10"
      DRONE_RPC_SECRET: "drone_rpc_secret"
      DRONE_RPC_HOST: "drone.example.com"
      DRONE_RPC_PROTO: "https"
    volumes:
      - "/var/run/docker.sock:/var/run/docker.sock"
```
***Заменить `drone_*`, `gitea_*` и `*.example.com` на ваши значения**